/**
 * External dependencies
 */
import Hashes from 'jshashes';
import qs from 'querystring';
import deterministicStringify from 'lib/deterministic-stringify';

/**
 * Internal dependencies
 */
import { SYNC_RECORD_NAMESPACE } from './constants';

/**
 * Generate a key from the given param object
 *
 * @param {Object} params - request parameters
 * @param {Boolean} applyHash - codificate key when it's true
 * @return {String} request key
 */
export const generateKey = ( params, applyHash = true ) => {
	var key = `${params.apiVersion || ''}-${params.method}-${params.path}`;

	if ( params.query ) {
		// sort parameters alphabetically
		key += '-' + deterministicStringify( qs.parse( params.query ) );
	}

	if ( applyHash ) {
		key = new Hashes.SHA1().hex( key );
	}

	key = SYNC_RECORD_NAMESPACE + key;
	return key;
}

/**
 * Generate pageSeriesKey from request parameters
 * @param  {Object} reqParams - request parameters
 * @return {String}        - pageSeriesKey string
 */
export const generatePageSeriesKey = ( reqParams ) => {
	const queryParams = qs.parse( reqParams.query );
	delete queryParams.page_handle;
	const paramsWithoutPage = Object.assign( {}, reqParams, { query: qs.stringify( queryParams ) } );
	return generateKey( paramsWithoutPage );
}
